@@ -17,8 +17,7 @@
 #' x <- read_xml("<p>   Some text    </p>")
 #' xml_text(x, trim = TRUE)
 #'
-#' # xml_double() and xml_integer() are useful for extracting numeric
-#' attributes
+#' # xml_double() and xml_integer() are useful for extracting numeric attributes
 #' x <- read_xml("<plot><point x='1' y='2' /><point x='2' y='1' /></plot>")
 #' xml_integer(xml_find_all(x, "//@x"))
 #' @export
@@ -33,7 +32,7 @@ xml_text.xml_missing <- function(x, trim = FALSE) {
 
 #' @export
 xml_text.xml_node <- function(x, trim = FALSE) {
-  res <- node_text(x$node)
+  res <- .Call(node_text, x$node)
   if (isTRUE(trim)) {
     res <- sub("^[[:space:]\u00a0]+", "", res)
     res <- sub("[[:space:]\u00a0]+$", "", res)
@@ -72,12 +71,12 @@ xml_text.xml_nodeset <- function(x, trim = FALSE) {
   if (xml_type(x) != "text") {
     text_child <- xml_find_first(x, ".//text()[1]", ns = character())
     if (inherits(text_child, "xml_missing")) {
-      node_append_content(x$node, value)
+      .Call(node_append_content, x$node, value)
     } else {
-      node_set_content(text_child$node, value)
+      .Call(node_set_content, text_child$node, value)
     }
   } else {
-    node_set_content(x$node, value)
+    .Call(node_set_content, x$node, value)
   }
 
   x
